#
# spec file for package python-application
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-application
Version:        3.0.3
Release:        2.14
Summary:        Basic building blocks for Python applications
License:        LGPL-2.1-or-later
Group:          Development/Libraries/Python
URL:            https://github.com/AGProjects/python3-application
Source:         https://github.com/AGProjects/python3-application/archive/refs/tags/%{version}.tar.gz#/python3-application-%{version}.tar.gz
# PATCH-FIX-UPSTREAM examples_to_py3k.patch gh#AGProjects/python3-application#2 mcepl@suse.com
# Replace py2k shebangs with py3k ones
Patch0:         examples_to_py3k.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
This module provides some basic components that can be used to simplify
building Python applications.

The components included by this package encapsulate the functionality to
handle the following tasks:

 - UNIX process management (forking, signal handling, pid file creation)
 - A very simple to use interface to handle .ini configuration files.
 - An extensible system logger for console and/or syslog.
 - Miscellaneous utilities and helpers.
 - Memory troubleshooting and execution timing.
 - Communicate inside the application using a notification system.
 - Manage the version number for applications, modules and packages.

%prep
%autosetup -p1 -n python3-application-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# testsuite does not exist yet

%files %{python_files}
%license LICENSE
%doc ChangeLog NEWS README examples/
%{python_sitelib}/application
%{python_sitelib}/python*_application*

%changelog
* Mon Aug 30 2021 Matej Cepl <mcepl@suse.com>
- Add examples_to_py3k.patch to remove py2k shebangs
  (gh#AGProjects/python3-application#2).
* Fri Aug 27 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 3.0.3
  * Fixed writing process pid.
- Update to version 3.0.2
  * Fixed queue.
- Update to version 3.0.1
  * Fixed crash when using capture_output function.
- Update to version 3.0.0
  * Migrate to python3.
- Update to version 2.8.0
  * Fixed issue with the syslog handler and null bytes in messages.
  * Call handleError on SyslogHandler when exception happens during
    emit.
  * Added some utility functions for setting up the log system
    + Added set_handler function to set the main handler used by
    logging (it will replace all existing handlers on the root
    logger).
    + Added capture_output function to capture and divert standard
    output and standard error to the logging system.
  * Replaced start_syslog with use_syslog and deprecated the
    former.
  * Improved detection of non-interactive mode.
  * Renamed IfNotInteractive to WhenNotInteractive.
  * Use the real path for runtime and config directories (follow
    symlinks).
  * Added daemon property on Process to check if it's in daemon
    mode or not.
  * Check exc_type instead of exc_value in the context manager's
    __exit__ .
  * Added module level log function to the log module similar to
    logging.log .
  * Use the with statement instead of try/finally.
  * Fixed broad exception statement.
  * Normalize names for descriptor method arguments.
  * Removed docstrings from internal functions.
  * Refactored configuration and runtime settings on Process.
  * Make the local_root undefined when running from system binary
    paths.
  * Only ignore OSError in unlink wrapper.
  * Use the new octal notation for file modes.
  * Fixed spelling in exception message.
  * Ordered imports alphabetically.
  * Explicitly use python2 in shebang lines.
* Sun Nov 17 2019 Martin Hauke <mardnh@gmx.de>
- Convert inline changelog to python-application.changes
- Drop patch (obsolete)
  * python-application-1.0.9.dif
* Thu Sep 27 2007 poeml@suse.de
- fixed build, adding python-application-1.0.9.dif
  Mon Sep 24 00:00:00 UTC 2007 - Peter Nixon
- Initial release
